<?php 
$translations = array(
	'General_Locale' => 'fr_FR.UTF-8',
	'General_TranslatorName' => 'Vincent BIRET',
	'General_TranslatorEmail' => 'admin@get-surf.com',
	'General_EnglishLanguageName' => 'French',
	'General_OriginalLanguageName' => 'Français',
	'General_HelloUser' => 'Bonjour, %s',
	'General_OpenSourceWebAnalytics' => 'Analyse web libre',
	'General_YourDashboard' => 'Votre tableau de bord',
	'General_API' => 'API',
	'General_Widgets' => 'Widgets',
	'General_Settings' => 'Paramètres',
	'General_GiveUsYourFeedback' => 'Envoyez-nous vos commentaires !',
	'General_Unknown' => 'Inconnu',
	'General_Required' => '%s requis',
	'General_Error' => 'Erreur',
	'General_Warning' => 'Attention',
	'General_BackToHomepage' => 'Retour à la page d\'accueil Piwik',
	'General_Yes' => 'Oui',
	'General_No' => 'Non',
	'General_Delete' => 'Supprimer',
	'General_Edit' => 'Éditer',
	'General_Ok' => 'Ok',
	'General_Close' => 'Fermer',
	'General_Logout' => 'Déconnexion',
	'General_Done' => 'Fait',
	'General_LoadingData' => 'Chargement des données...',
	'General_Loading' => 'Chargement...',
	'General_ErrorRequest' => 'Oups ! Problème rencontré durant la requête, veuillez réessayer.',
	'General_Next' => 'Suivant',
	'General_Previous' => 'Précédent',
	'General_Search' => 'Rechercher',
	'General_Others' => 'Autres',
	'General_Table' => 'Tableau',
	'General_Piechart' => 'Pointe de tarte',
	'General_TagCloud' => 'Nuage de tags',
	'General_VBarGraph' => 'Histogramme vertical',
	'General_Export' => 'Exporter',
	'General_ExportAsImage_js' => 'Exporter au format Image',
	'General_SaveImageOnYourComputer' => 'Pour enregistrer l\'image sur votre ordinateur, faites un clic droit sur l\'image et sélectionnez "Enregistrer l\'image sous..."',
	'General_Refresh' => 'Rafraîchir la page',
	'General_Visitors' => 'Visiteurs',
	'General_ColumnNbUniqVisitors' => 'Visiteurs uniques',
	'General_ColumnNbVisits' => 'Visites',
	'General_ColumnNbActions' => 'Actions',
	'General_ColumnMaxActions' => 'Nombre maximum d\'actions en une visite',
	'General_ColumnSumVisitLength' => 'Temps total passé par les visiteurs (en secondes)',
	'General_ColumnLabel' => 'Nom',
	'General_ColumnActionsPerVisit' => 'Actions par visite',
	'General_ColumnAvgTimeOnSite' => 'Temps moyen sur le site',
	'General_ColumnBounceRate' => 'Taux de rebond',
	'General_ColumnPageviews' => 'Vues',
	'General_ColumnUniquePageviews' => 'Vues uniques',
	'General_ColumnValuePerVisit' => 'Valeur par Visite',
	'General_ColumnVisitsWithConversions' => 'Visites avec Conversions',
	'General_Save' => 'Enregistrer',
	'General_Website' => 'Site',
	'General_RequiresFlash' => 'L\'affichage des Graphs dans Piwik requiert Flash',
	'General_GraphHelp' => 'Plus d\'informations à propos de l\'affichage des graphs dans Piwik.',
	'General_NoDataForGraph' => 'Aucune donnée pour ce graphique',
	'General_NoDataForTagCloud' => 'Aucune donnée pour ce nuage de tags.',
	'General_DisplayNormalTable' => 'Voir tableau normal',
	'General_DisplayMoreData' => 'Voir plus de données',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%s Piwik %s est un projet collaboratif. %s Si vous aimez Piwik, vous pouvez nous aider! Allez voir %s Comment contribuer à Piwik?%s ',
	'General_YouAreCurrentlyViewingDemoOfPiwik' => 'Vous êtes dans la démo de %s; %stéléchargez%s la version complète ! Visitez %s.',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %s est maintenant disponible. %s Merci de mettre à jour!%s (voir %s les modifications%s).',
	'General_BackToPiwik' => 'Retourner à Piwik',
	'General_ShortMonth_1' => 'Jan',
	'General_ShortMonth_2' => 'Fév',
	'General_ShortMonth_3' => 'Mar',
	'General_ShortMonth_4' => 'Avr',
	'General_ShortMonth_5' => 'Mai',
	'General_ShortMonth_6' => 'Jun',
	'General_ShortMonth_7' => 'Jul',
	'General_ShortMonth_8' => 'Aoû',
	'General_ShortMonth_9' => 'Sep',
	'General_ShortMonth_10' => 'Oct',
	'General_ShortMonth_11' => 'Nov',
	'General_ShortMonth_12' => 'Dec',
	'General_LongMonth_1' => 'Janvier',
	'General_LongMonth_2' => 'Février',
	'General_LongMonth_3' => 'Mars',
	'General_LongMonth_4' => 'Avril',
	'General_LongMonth_5' => 'Mai',
	'General_LongMonth_6' => 'Juin',
	'General_LongMonth_7' => 'Juillet',
	'General_LongMonth_8' => 'Août',
	'General_LongMonth_9' => 'Septembre',
	'General_LongMonth_10' => 'Octobre',
	'General_LongMonth_11' => 'Novembre',
	'General_LongMonth_12' => 'Décembre',
	'General_ShortDay_1' => 'Lun',
	'General_ShortDay_2' => 'Mar',
	'General_ShortDay_3' => 'Mer',
	'General_ShortDay_4' => 'Jeu',
	'General_ShortDay_5' => 'Ven',
	'General_ShortDay_6' => 'Sam',
	'General_ShortDay_7' => 'Dim',
	'General_LongDay_1' => 'Lundi',
	'General_LongDay_2' => 'Mardi',
	'General_LongDay_3' => 'Mercredi',
	'General_LongDay_4' => 'Jeudi',
	'General_LongDay_5' => 'Vendredi',
	'General_LongDay_6' => 'Samedi',
	'General_LongDay_7' => 'Dimanche',
	'General_ExceptionDatabaseVersion' => 'Votre version de %s est %s mais Piwik a besoin au minimum de la version %s.',
	'CorePluginsAdmin_Plugins' => 'Plugins',
	'CorePluginsAdmin_PluginsManagement' => 'Gestionnaire de plugins',
	'CorePluginsAdmin_MainDescription' => 'Les plugins étendent et ajoutent des fonctionnalités à Piwik. Une fois un plugin installé, vous pouvez l\'activer ou le désactiver ici.',
	'CorePluginsAdmin_Plugin' => 'Plugin',
	'CorePluginsAdmin_Version' => 'Version',
	'CorePluginsAdmin_Description' => 'Description',
	'CorePluginsAdmin_Status' => 'État',
	'CorePluginsAdmin_Action' => 'Action',
	'CorePluginsAdmin_PluginHomepage' => 'Page d\'accueil du plugin',
	'CorePluginsAdmin_Activated' => 'Activé',
	'CorePluginsAdmin_Active' => 'Actif',
	'CorePluginsAdmin_Inactive' => 'Inactif',
	'CorePluginsAdmin_ActivatedHelp' => 'Ce plugin ne peut être désactivé',
	'CorePluginsAdmin_Deactivate' => 'Désactiver',
	'CorePluginsAdmin_Activate' => 'Activer',
	'CorePluginsAdmin_MenuPlugins' => 'Plugins',
	'API_QuickDocumentation' => '<h2>Documentation rapide de l\'API</h2><p>Si vous n\'avez pas de données pour ajourd\'hui, vous pouvez d\'abord  <a href=\'misc/generateVisits.php\' target=_blank>générer des données</a> en utilisant le Générateur de Visites.</p><p>Vous pouvez essayer les différents formats disponibles pour chaque méthode. Il est très facile d\'extraire n\'importe quelle donnée que vous voulez de Piwik!</p><p><b>Pour plus d\'informations visitez la <a href=\'http://dev.piwik.org/trac/wiki/API\'>Documentation officielle de l\'API</a> or the <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>Référence API</a>.</b></P><h2>Identification</h2><p>Si vous voulez <b>utiliser les données dans vos scripts, dans une crontab, etc. </b> vous devez ajouter le paramètre <code><u>&token_auth=%s</u></code> to the API calls URLs that require authentication.</p><p>Cette token_auth est aussi secrètes que votre nom d\'utilisateur ou votre mot de passe, <b>ne la partagez pas!</p>',
	'API_LoadedAPIs' => '%s API chargées avec succès',
	'CoreHome_NoPrivileges' => 'Vous êtes connecté en tant que \'%s\' mais il semble que vous n\'ayez aucune permission dans Piwik.<br />Demandez à votre administrateur Piwik de vous accorder l\'accès type \'view\' à un site Internet.',
	'CoreHome_JavascriptDisabled' => 'JavaScript doit être activé dans votre navigateur pour pouvoir utiliser Piwik en mode standard.<br />Il semble que JavaScript soit désactivé ou qu\'il ne soit pas supporté par votre navigateur.<br />Pour utiliser Piwik en mode standard activez JS via les options de votre navigateur et essayez à nouveau.<br />',
	'CoreHome_TableNoData' => 'Aucune donnée pour ce tableau.',
	'CoreHome_CategoryNoData' => 'Aucune donnée pour cette catégorie. Essayez en cliquant sur "Inclure toute la population".',
	'CoreHome_ShowJSCode' => 'Afficher le tag JavaScript à insérer',
	'CoreHome_IncludeAllPopulation_js' => 'Inclure toute la population',
	'CoreHome_ExcludeLowPopulation_js' => 'Exclure les petites populations des statistiques',
	'CoreHome_PageOf_js' => '%s de %s',
	'CoreHome_Loading_js' => 'Chargement...',
	'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
	'CoreHome_PeriodDay' => 'Jour',
	'CoreHome_PeriodWeek' => 'Semaine',
	'CoreHome_PeriodMonth' => 'Mois',
	'CoreHome_PeriodYear' => 'Année',
	'CoreHome_PeriodDays' => 'jours',
	'CoreHome_PeriodWeeks' => 'semaines',
	'CoreHome_PeriodMonths' => 'mois',
	'CoreHome_PeriodYears' => 'années',
	'CoreHome_DaySu_js' => 'Di',
	'CoreHome_DayMo_js' => 'Lu',
	'CoreHome_DayTu_js' => 'Ma',
	'CoreHome_DayWe_js' => 'Me',
	'CoreHome_DayTh_js' => 'Je',
	'CoreHome_DayFr_js' => 'Ve',
	'CoreHome_DaySa_js' => 'Sa',
	'CoreHome_ShortDay_1_js' => 'Dim',
	'CoreHome_ShortDay_2_js' => 'Lun',
	'CoreHome_ShortDay_3_js' => 'Mar',
	'CoreHome_ShortDay_4_js' => 'Mer',
	'CoreHome_ShortDay_5_js' => 'Jeu',
	'CoreHome_ShortDay_6_js' => 'Ven',
	'CoreHome_ShortDay_7_js' => 'Sam',
	'CoreHome_LongDay_1_js' => 'Dimanche',
	'CoreHome_LongDay_2_js' => 'Lundi',
	'CoreHome_LongDay_3_js' => 'Mardi',
	'CoreHome_LongDay_4_js' => 'Mercredi',
	'CoreHome_LongDay_5_js' => 'Jeudi',
	'CoreHome_LongDay_6_js' => 'Vendredi',
	'CoreHome_LongDay_7_js' => 'Samedi',
	'CoreHome_ShortMonth_1_js' => 'Jan',
	'CoreHome_ShortMonth_2_js' => 'Fév',
	'CoreHome_ShortMonth_3_js' => 'Mar',
	'CoreHome_ShortMonth_4_js' => 'Avr',
	'CoreHome_ShortMonth_5_js' => 'Mai',
	'CoreHome_ShortMonth_6_js' => 'Jun',
	'CoreHome_ShortMonth_7_js' => 'Jul',
	'CoreHome_ShortMonth_8_js' => 'Aoû',
	'CoreHome_ShortMonth_9_js' => 'Sep',
	'CoreHome_ShortMonth_10_js' => 'Oct',
	'CoreHome_ShortMonth_11_js' => 'Nov',
	'CoreHome_ShortMonth_12_js' => 'Déc',
	'CoreHome_MonthJanuary_js' => 'Janvier',
	'CoreHome_MonthFebruary_js' => 'Février',
	'CoreHome_MonthMarch_js' => 'Mars',
	'CoreHome_MonthApril_js' => 'Avril',
	'CoreHome_MonthMay_js' => 'Mai',
	'CoreHome_MonthJune_js' => 'Juin',
	'CoreHome_MonthJuly_js' => 'Juillet',
	'CoreHome_MonthAugust_js' => 'Août',
	'CoreHome_MonthSeptember_js' => 'Septembre',
	'CoreHome_MonthOctober_js' => 'Octobre',
	'CoreHome_MonthNovember_js' => 'Novembre',
	'CoreHome_MonthDecember_js' => 'Décembre',
	'CoreUpdater_UpdateTitle' => 'Piwik &rsaquo; Mise à jour',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Mise à jour de la base de données requise',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Votre base de données est expirée et doit être mise à jour avant de pouvoir continuer.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'La base de données de Piwik sera mise à jour depuis la version %s vers la version %s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Les plugins suivants seront mis à jour : %s.',
	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => 'Si votre base de données Piwik est trop volumineuse, la mise à jour pourra être trop longue pour l\'effectuer depuis le navigateur. dans ce cas exécutez depuis la ligne de commande : %s',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Le procédé de mise à jour peut être long, veuillez patienter.',
	'CoreUpdater_UpgradePiwik' => 'Mettez Piwik à jour',
	'CoreUpdater_ErrorDIYHelp' => 'Si vous êtes un utilisateur avancé et que vous rencontrez une erreur lors de la mise à jour de la base de données :',
	'CoreUpdater_ErrorDIYHelp_1' => 'identifiez la source exacte du problème (ex, memory_limit ou max_execution_time)',
	'CoreUpdater_ErrorDIYHelp_2' => 'exécutez les requêtes restantes qui ont échoué',
	'CoreUpdater_ErrorDIYHelp_3' => 'mettez à jour manuellement la table `otpion` de votre base de données Piwik, en spécifiant la valeur de version_core à la version de celle de l\'échec de la mise à jour',
	'CoreUpdater_ErrorDIYHelp_4' => 'ré-exécutez le gestionnaire de mise à jour (en commande ou via le navigateur) pour continuer l\'installation des mises à jour restantes',
	'CoreUpdater_ErrorDIYHelp_5' => 'rapportez le problème et la solution à Piwik, de cette manière il pourra être vérifié et distribué',
	'CoreUpdater_HelpMessageContent' => 'Consultez la %s FAQ Piwik %s qui tente d\'expliquer les erreurs les plus communes lors des mises à jour. $s Demandez à votre administrateur système, il pourrait être capable de vous aider à corriger l\'erreur qui est fort probablement reliée à votre serveur ou configuration MySQL.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Erreur Critique pendant le procédé de mise à jour :',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Ci-dessus est le message d\'erreur du noyau. Cela devrait expliquer la cause, mais si vous nécessitez d\'avantage d\'aide merci de :',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'La mise à jour a été complétée avec succès. Cependant, des problèmes sont survenus. Lisez la description ci-dessus pour plus de détails. Pour d\'avantage d\'aide :',
	'CoreUpdater_UpgradeComplete' => 'Mise à jour complète !',
	'CoreUpdater_WarningMessages' => 'Messages d\'avertissement :',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Erreurs pendant les mises à jour de plugins :',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Nous avons automatiquement désactivé les plugins suivants : %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik a été mis à jour avec succès !',
	'CoreUpdater_ContinueToPiwik' => 'Continuer vers Piwik',
	'CoreUpdater_UpdateAutomatically' => 'Mettre à jour automatiquement',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Il y a une nouvelle mise à jour de Piwik disponible',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Vous pouvez mettre à jour vers la version %s automatiquement ou télécharger l\'archive et l\'installer manuellement:',
	'CoreUpdater_DownloadX' => 'Télécharger %s',
	'CoreUpdater_UpdateHasBeenCancelled' => 'La mise à jour a été annulée.',
	'CoreUpdater_DownloadingUpdateFromX' => 'Téléchargement de la mise à jour depuis %s',
	'CoreUpdater_UnpackingTheUpdate' => 'Décompression de la mise à jour',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Vérification des fichiers décompressés',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Création d\'un backup du fichier de configuration dans le répertoire %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Installation de la dernière version',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik a été mis à jour avec succès!',
	'CoreUpdater_EmptyDatabaseError' => 'La base de données %s est vide. Vous devez éditer ou supprimer votre fichier de configuration Piwik.',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Votre version de Piwik %s est à jour.',
	'CoreUpdater_ExceptionArchiveIncompatible' => 'Archive incompatible: %s',
	'CoreUpdater_ExceptionArchiveEmpty' => 'Archive vide.',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'L\'archive est incomplète: des fichiers sont manquants (ex. %s).',
	'Actions_Actions' => 'Actions',
	'Actions_SubmenuPages' => 'Pages',
	'Actions_SubmenuPageTitles' => 'Titres de la page',
	'Actions_SubmenuOutlinks' => 'Liens de sortie',
	'Actions_SubmenuDownloads' => 'Téléchargements',
	'Actions_ColumnClicks' => 'Clics',
	'Actions_ColumnUniqueClicks' => 'Clics uniques',
	'Actions_ColumnDownloads' => 'Téléchargements',
	'Actions_ColumnUniqueDownloads' => 'Téléchargements uniques',
	'Actions_ColumnPageName' => 'Nom de la page',
	'Actions_ColumnPageURL' => 'URL de la page',
	'Actions_ColumnClickedURL' => 'URL sélectionnée',
	'Actions_ColumnDownloadURL' => 'URL de téléchargement',
	'Dashboard_Dashboard' => 'Tableau de bord',
	'Dashboard_AddWidget' => 'Ajouter un widget...',
	'Dashboard_DeleteWidgetConfirm' => 'Êtes-vous sûr de vouloir supprimer ce widget du tableau de bord?',
	'Dashboard_SelectWidget' => 'Sélectionnez le widget à ajouter au tableau de bord',
	'Dashboard_AddPreviewedWidget_js' => 'Ajouter le widget visualisé au tableau de bord',
	'Dashboard_WidgetPreview_js' => 'Prévisualisation du Widget',
	'Dashboard_Close_js' => 'Fermer',
	'Dashboard_TitleWidgetInDashboard_js' => 'Widget déjà présent sur le tableau de bord',
	'Dashboard_TitleClickToAdd_js' => 'Cliquez pour ajouter au tableau de bord',
	'Dashboard_LoadingWidget_js' => 'Chargement du widget, patientez svp...',
	'Dashboard_WidgetNotFound_js' => 'Widget introuvable',
	'Referers_Referers' => 'Référents',
	'Referers_SearchEngines' => 'Moteurs de recherche',
	'Referers_Keywords' => 'Mots-clés',
	'Referers_DirectEntry' => 'Entrées directes',
	'Referers_Websites' => 'Sites Internet',
	'Referers_Campaigns' => 'Campagnes',
	'Referers_MetricsFromRefererTypeGraphLegend' => '%1s (en %2s)',
	'Referers_Evolution' => 'Évolution sur la période',
	'Referers_Type' => 'Types d\'affluents',
	'Referers_ColumnRefererType' => 'Type de Provenance',
	'Referers_ColumnSearchEngine' => 'Moteur de recherche',
	'Referers_ColumnWebsite' => 'Site Web',
	'Referers_ColumnWebsitePage' => 'Page du site',
	'Referers_ColumnKeyword' => 'Mot clef',
	'Referers_ColumnCampaign' => 'Campagne',
	'Referers_DetailsByRefererType' => 'Détails de types d\'affluents',
	'Referers_TypeDirectEntries' => '%s entrées directes',
	'Referers_TypeSearchEngines' => '%s depuis des moteurs de recherche',
	'Referers_TypeWebsites' => '%s depuis d\'autres sites Internet',
	'Referers_TypeCampaigns' => '%s depuis des campagnes',
	'Referers_Distinct' => 'Provenances distinctes par type de Provenance',
	'Referers_DistinctSearchEngines' => 'Moteurs de recherche distincts',
	'Referers_DistinctKeywords' => 'mots clef distincts',
	'Referers_DistinctCampaigns' => 'campagnes distinctes',
	'Referers_DistinctWebsites' => 'sites web distincts',
	'Referers_UsingNDistinctUrls' => ' (utilisant %2s url distinctes)',
	'Referers_SubmenuEvolution' => 'Évolution',
	'Referers_SubmenuSearchEngines' => 'Moteurs de recherche et mots-clés',
	'Referers_SubmenuWebsites' => 'Sites Internet',
	'Referers_SubmenuCampaigns' => 'Campagnes',
	'Referers_WidgetKeywords' => 'Liste des mots-clés',
	'Referers_WidgetCampaigns' => 'Liste des campagnes',
	'Referers_WidgetExternalWebsites' => 'Liste des sites Internet externes',
	'Referers_WidgetSearchEngines' => 'Meilleurs moteurs de recherche',
	'Referers_WidgetOverview' => 'Récapitulatif',
	'UserSettings_VisitorSettings' => 'Paramètres visiteur',
	'UserSettings_BrowserFamilies' => 'Familles de navigateurs',
	'UserSettings_Browsers' => 'Navigateurs',
	'UserSettings_Plugins' => 'Plugins',
	'UserSettings_Configurations' => 'Configurations',
	'UserSettings_OperatinsSystems' => 'Système d\'exploitation',
	'UserSettings_Resolutions' => 'Résolutions',
	'UserSettings_WideScreen' => 'Largeur d\'écran',
	'UserSettings_ColumnBrowserFamily' => 'Famille de navigateur',
	'UserSettings_ColumnBrowser' => 'navigateur',
	'UserSettings_ColumnPlugin' => 'Plugin',
	'UserSettings_ColumnConfiguration' => 'Configuration',
	'UserSettings_ColumnOperatinsSystem' => 'Système d\'exploitation',
	'UserSettings_ColumnResolution' => 'Résolution',
	'UserSettings_ColumnTypeOfScreen' => 'Type d\'écran',
	'UserSettings_WidgetResolutions' => 'Résolutions d\'écran',
	'UserSettings_WidgetBrowsers' => 'Navigateurs du visiteur',
	'UserSettings_WidgetPlugins' => 'Liste de Plugins',
	'UserSettings_WidgetWidescreen' => 'Normal / Écran large',
	'UserSettings_WidgetBrowserFamilies' => 'Navigateurs par famille',
	'UserSettings_WidgetOperatingSystems' => 'Systèmes d\'exploitation',
	'UserSettings_WidgetGlobalVisitors' => 'Configuration globale des visiteurs',
	'UserSettings_SubmenuSettings' => 'Paramètres',
	'UserCountry_Country' => 'Pays',
	'UserCountry_Continent' => 'Continent',
	'UserCountry_DistinctCountries' => '%s pays différents',
	'UserCountry_SubmenuLocations' => 'Provenances géographiques',
	'UserCountry_WidgetContinents' => 'Continents des visiteurs',
	'UserCountry_WidgetCountries' => 'Pays des visiteurs',
	'UserCountry_country_ac' => 'Ascension (île)',
	'UserCountry_country_ad' => 'Andorre',
	'UserCountry_country_ae' => 'Émirats arabes unis',
	'UserCountry_country_af' => 'Afghanistan',
	'UserCountry_country_ag' => 'Antigua et Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albanie',
	'UserCountry_country_am' => 'Armenie',
	'UserCountry_country_an' => 'Antilles Néerlandaises',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antarctique',
	'UserCountry_country_ar' => 'Argentine',
	'UserCountry_country_as' => 'Samoa Amercicaines',
	'UserCountry_country_at' => 'Autriche',
	'UserCountry_country_au' => 'Australie',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'État libre associé d\'Åland',
	'UserCountry_country_az' => 'Azerbaijan',
	'UserCountry_country_ba' => 'Bosnie-Herzegovine',
	'UserCountry_country_bb' => 'La Barbade',
	'UserCountry_country_bd' => 'Bangladesh',
	'UserCountry_country_be' => 'Belgique',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgarie',
	'UserCountry_country_bh' => 'Bahrein',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Bénin',
	'UserCountry_country_bl' => 'Saint Barthelemy',
	'UserCountry_country_bm' => 'Bermudes',
	'UserCountry_country_bn' => 'Brunei',
	'UserCountry_country_bo' => 'Bolivie',
	'UserCountry_country_br' => 'Brésil',
	'UserCountry_country_bs' => 'Bahamas',
	'UserCountry_country_bt' => 'Bhutan',
	'UserCountry_country_bu' => 'Union du Myanmar',
	'UserCountry_country_bv' => 'Ile Bouvet',
	'UserCountry_country_bw' => 'Botswana',
	'UserCountry_country_by' => 'Belarus',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Canada',
	'UserCountry_country_cc' => 'Iles des Cocos (Keeling)',
	'UserCountry_country_cd' => 'Congo, République démocratique du',
	'UserCountry_country_cf' => 'République d\'Afrique Centrale',
	'UserCountry_country_cg' => 'Congo',
	'UserCountry_country_ch' => 'Suisse',
	'UserCountry_country_ci' => 'Cote D\'Ivoire',
	'UserCountry_country_ck' => 'Iles Cook',
	'UserCountry_country_cl' => 'Chili',
	'UserCountry_country_cm' => 'Cameroon',
	'UserCountry_country_cn' => 'Chine',
	'UserCountry_country_co' => 'Colombie',
	'UserCountry_country_cp' => 'Ile de La Passion',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Serbie Montenegro',
	'UserCountry_country_cu' => 'Cuba',
	'UserCountry_country_cv' => 'Cap Vert',
	'UserCountry_country_cx' => 'Ile Christmas',
	'UserCountry_country_cy' => 'Chypres',
	'UserCountry_country_cz' => 'Republique Tchèque',
	'UserCountry_country_de' => 'Allemagne',
	'UserCountry_country_dg' => 'Diego Garcia',
	'UserCountry_country_dj' => 'Djibouti',
	'UserCountry_country_dk' => 'Danemark',
	'UserCountry_country_dm' => 'Dominique',
	'UserCountry_country_do' => 'Republique Dominicaine',
	'UserCountry_country_dz' => 'Algerie',
	'UserCountry_country_ea' => 'Ceuta, Melilla',
	'UserCountry_country_ec' => 'Équateur',
	'UserCountry_country_ee' => 'Estonie',
	'UserCountry_country_eg' => 'Égypte',
	'UserCountry_country_eh' => 'Sahara occidental',
	'UserCountry_country_er' => 'Erythrée',
	'UserCountry_country_es' => 'Espagne',
	'UserCountry_country_et' => 'Ethiopie',
	'UserCountry_country_eu' => 'Union Européenne',
	'UserCountry_country_fi' => 'Finlande',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Iles Falkland',
	'UserCountry_country_fm' => 'Micronesia, Federated States of',
	'UserCountry_country_fo' => 'Iles Faroe',
	'UserCountry_country_fr' => 'France',
	'UserCountry_country_fx' => 'France metropolitaine',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Grande Bretagne',
	'UserCountry_country_gd' => 'Grenade',
	'UserCountry_country_ge' => 'Georgie',
	'UserCountry_country_gf' => 'Guyanne Française',
	'UserCountry_country_gg' => 'Ile de Guernesey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Groenland',
	'UserCountry_country_gm' => 'Gambie',
	'UserCountry_country_gn' => 'Guinée',
	'UserCountry_country_gp' => 'Guadeloupe',
	'UserCountry_country_gq' => 'Guinée Équatoriale',
	'UserCountry_country_gr' => 'Grèce',
	'UserCountry_country_gs' => 'Géorgie du Sud-et-les Îles Sandwich du Sud',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinée-Bissau',
	'UserCountry_country_gy' => 'Guyanne',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Iles heard et Mac Donald',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Croatie',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Hongrie',
	'UserCountry_country_ic' => 'Iles Canaries',
	'UserCountry_country_id' => 'Indonesie',
	'UserCountry_country_ie' => 'Irlande',
	'UserCountry_country_il' => 'Israel',
	'UserCountry_country_im' => 'Iles de Man',
	'UserCountry_country_in' => 'Inde',
	'UserCountry_country_io' => 'Océan indien (Territoire Britanique)',
	'UserCountry_country_iq' => 'Irak',
	'UserCountry_country_ir' => 'Iran, République Islamique de',
	'UserCountry_country_is' => 'Islande',
	'UserCountry_country_it' => 'Italie',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaïque',
	'UserCountry_country_jo' => 'Jordanie',
	'UserCountry_country_jp' => 'Japon',
	'UserCountry_country_ke' => 'Kenya',
	'UserCountry_country_kg' => 'Kyrgyzstan',
	'UserCountry_country_kh' => 'Kampuchea (ex Cambodge)',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Comores',
	'UserCountry_country_kn' => 'Saint Christophe Nieves Ang.',
	'UserCountry_country_kp' => 'Corée du Nord',
	'UserCountry_country_kr' => 'Corée du Sud',
	'UserCountry_country_kw' => 'Koweit',
	'UserCountry_country_ky' => 'Iles Caimans',
	'UserCountry_country_kz' => 'Kazakhstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Liban',
	'UserCountry_country_lc' => 'Sainte Lucie',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Liberia',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Lituanie',
	'UserCountry_country_lu' => 'Luxembourg',
	'UserCountry_country_lv' => 'Lettonie',
	'UserCountry_country_ly' => 'Lybie',
	'UserCountry_country_ma' => 'Maroc',
	'UserCountry_country_mc' => 'Monaco',
	'UserCountry_country_md' => 'Moldava',
	'UserCountry_country_me' => 'Monténégro',
	'UserCountry_country_mf' => 'Saint Martin',
	'UserCountry_country_mg' => 'Madagascar',
	'UserCountry_country_mh' => 'Iles Marshall',
	'UserCountry_country_mk' => 'Macédonie',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongolie',
	'UserCountry_country_mo' => 'Macao',
	'UserCountry_country_mp' => 'Iles Mariannes du Nord',
	'UserCountry_country_mq' => 'Martinique',
	'UserCountry_country_mr' => 'Mauritanie',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malte',
	'UserCountry_country_mu' => 'Ile Maurice',
	'UserCountry_country_mv' => 'Maldives',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mexique',
	'UserCountry_country_my' => 'Malaisie',
	'UserCountry_country_mz' => 'Mozambique',
	'UserCountry_country_na' => 'Namibie',
	'UserCountry_country_nc' => 'Nouvelle Calédonie',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Ile Norfolk',
	'UserCountry_country_ng' => 'Nigeria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Pays-Bas',
	'UserCountry_country_no' => 'Norvège',
	'UserCountry_country_np' => 'Népal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Zone Neutre',
	'UserCountry_country_nu' => 'Nioue',
	'UserCountry_country_nz' => 'Nouvelle Zélande',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Pérou',
	'UserCountry_country_pf' => 'Polynésie Française',
	'UserCountry_country_pg' => 'Papouasie Nouvelle Guinée',
	'UserCountry_country_ph' => 'Philippines',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Pologne',
	'UserCountry_country_pm' => 'Saint Pierre et Miquelon',
	'UserCountry_country_pn' => 'Iles Pitcairn',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Palestine',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguay',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'La Réunion',
	'UserCountry_country_ro' => 'Roumanie',
	'UserCountry_country_ru' => 'Russia',
	'UserCountry_country_rs' => 'Serbia',
	'UserCountry_country_rw' => 'Rwanda',
	'UserCountry_country_sa' => 'Arabie Saoudite',
	'UserCountry_country_sb' => 'Iles Solomon',
	'UserCountry_country_sc' => 'Seychelles',
	'UserCountry_country_sd' => 'Soudan',
	'UserCountry_country_se' => 'Suède',
	'UserCountry_country_sf' => 'Finlande',
	'UserCountry_country_sg' => 'Singapour',
	'UserCountry_country_sh' => 'Sainte Hélène',
	'UserCountry_country_si' => 'Slovenie',
	'UserCountry_country_sj' => 'Svalbard et Ile Jan Mayen',
	'UserCountry_country_sk' => 'Slovaquie',
	'UserCountry_country_sl' => 'Sierra Leone',
	'UserCountry_country_sm' => 'Saint-Marin',
	'UserCountry_country_sn' => 'Sénégal',
	'UserCountry_country_so' => 'Somalie',
	'UserCountry_country_sr' => 'Surinam',
	'UserCountry_country_st' => 'Sao Tome et Principe',
	'UserCountry_country_su' => 'Ex U.R.S.S',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Syrie',
	'UserCountry_country_sz' => 'Swaziland',
	'UserCountry_country_ta' => 'Île Tristan da Cunha',
	'UserCountry_country_tc' => 'Iles Turks et Caicos',
	'UserCountry_country_td' => 'Tchad',
	'UserCountry_country_tf' => 'Terres australes et antarctiques françaises',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Thaïlande',
	'UserCountry_country_tj' => 'Tajikistan',
	'UserCountry_country_tk' => 'Tokelaou',
	'UserCountry_country_tl' => 'Timor Oriental',
	'UserCountry_country_tm' => 'Turkmenistan',
	'UserCountry_country_tn' => 'Tunisie',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'Timor Oriental',
	'UserCountry_country_tr' => 'Turquie',
	'UserCountry_country_tt' => 'Trinité et Tobago ',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taïwan',
	'UserCountry_country_tz' => 'Tanzanie',
	'UserCountry_country_ua' => 'Ukraine',
	'UserCountry_country_ug' => 'Ouganda',
	'UserCountry_country_uk' => 'Royaume-Uni',
	'UserCountry_country_um' => 'Îles mineures éloignées des États-Unis',
	'UserCountry_country_us' => 'Etats Unis',
	'UserCountry_country_uy' => 'Uruguay',
	'UserCountry_country_uz' => 'Ouzbekistan',
	'UserCountry_country_va' => 'Vatican',
	'UserCountry_country_vc' => 'Saint Vincent et Grenadines',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Iles Vierges Britanniques',
	'UserCountry_country_vi' => 'Iles Vierges U.S.',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis and Futuna',
	'UserCountry_country_ws' => 'Samoa Occidentales',
	'UserCountry_country_ye' => 'Yemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Yugoslavie',
	'UserCountry_country_za' => 'Afrique du Sud',
	'UserCountry_country_zm' => 'Zambie',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Europe',
	'UserCountry_continent_afr' => 'Afrique',
	'UserCountry_continent_asi' => 'Asie',
	'UserCountry_continent_ams' => 'Amérique du sud et centrale',
	'UserCountry_continent_amn' => 'Amérique du nord',
	'UserCountry_continent_oce' => 'Océanie',
	'VisitsSummary_VisitsSummary' => 'Récapitulatif des visites',
	'VisitsSummary_NbVisits' => '%s visites',
	'VisitsSummary_NbUniqueVisitors' => '%s visiteurs uniques',
	'VisitsSummary_NbActions' => '%s actions (pages vues)',
	'VisitsSummary_TotalTime' => '%s temps total passé par les visiteurs',
	'VisitsSummary_MaxNbActions' => '%s actions maximums en une visite',
	'VisitsSummary_NbVisitsBounced' => '%s visiteurs ont survolé (quitté le site après une page)',
	'VisitsSummary_EvolutionOverLastPeriods' => 'Évolution sur les 30 derniers %s',
	'VisitsSummary_Report' => 'Rapport',
	'VisitsSummary_GenerateTime' => '%s secondes pour générer la page',
	'VisitsSummary_GenerateQueries' => '%s requêtes exécutées',
	'VisitsSummary_WidgetLastVisits' => 'Graphique des dernières visites',
	'VisitsSummary_WidgetVisits' => 'Récapitulatif des visites',
	'VisitsSummary_WidgetLastVisitors' => 'Graphique des derniers visiteurs uniques',
	'VisitsSummary_WidgetOverviewGraph' => 'Graphique récapitulatif',
	'VisitsSummary_SubmenuOverview' => 'Récapitulatif',
	'VisitFrequency_Evolution' => 'Évolution sur la période',
	'VisitFrequency_ColumnReturningVisits' => 'Visites retour',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'Actions des visites retour',
	'VisitFrequency_ColumnMaximumActionsByAReturningVisit' => 'Nombre maximum d\'actions par une visite retour',
	'VisitFrequency_ColumnTotalTimeSpentByReturningVisits' => 'Temps total passé par les visites retour (en secondes)',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Pourcentage de survolement par les visites retour',
	'VisitFrequency_ReturnVisits' => '%s visites de visiteurs connus',
	'VisitFrequency_ReturnActions' => '%s actions de visites de visiteurs connus',
	'VisitFrequency_ReturnMaxActions' => '%s actions maximums par visite de visiteur connus',
	'VisitFrequency_ReturnTotalTime' => '%s temps total passé par des visiteurs connus',
	'VisitFrequency_ReturnBounceRate' => '%s visiteurs connus ont survolé (quitté le site après une page)',
	'VisitFrequency_WidgetOverview' => 'Récapitulatif de la Fréquence',
	'VisitFrequency_WidgetGraphReturning' => 'Graphique de visites de visiteurs connus',
	'VisitFrequency_SubmenuFrequency' => 'Fréquence',
	'VisitTime_LocalTime' => 'Visites par heure locale',
	'VisitTime_ServerTime' => 'Visites par heure du serveur',
	'VisitTime_ColumnServerTime' => 'Heure serveur',
	'VisitTime_ColumnLocalTime' => 'Heure locale',
	'VisitTime_WidgetLocalTime' => 'Visites par fuseau horaire local',
	'VisitTime_WidgetServerTime' => 'Visites par fuseau horaire du serveur',
	'VisitTime_SubmenuTimes' => 'Horaires',
	'VisitTime_NHour' => '%sh',
	'VisitorInterest_VisitsPerDuration' => 'Visites par durée de la visite',
	'VisitorInterest_VisitsPerNbOfPages' => 'Visites par nombre de pages',
	'VisitorInterest_ColumnVisitDuration' => 'Durée de la visite',
	'VisitorInterest_ColumnPagesPerVisit' => 'Pages par visite',
	'VisitorInterest_WidgetLengths' => 'Durée des visites',
	'VisitorInterest_WidgetPages' => 'Pages par visite',
	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Fréquence et Fidélité',
	'VisitorInterest_PlusXMin' => '%s min',
	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min',
	'VisitorInterest_OnePage' => '1 page',
	'VisitorInterest_NPages' => '%s pages',
	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
	'Login_LoginPasswordNotCorrect' => 'Mot de passe et nom d\'utilisateur incorrects.',
	'Login_Login' => 'Nom d\'utilisateur',
	'Login_Password' => 'Mot de passe',
	'Login_PasswordRepeat' => 'Mot de passe (répétez)',
	'Login_ChangePassword' => 'Modifier le mot de passe',
	'Login_LoginOrEmail' => 'Nom d\'utilisateur ou courriel',
	'Login_LogIn' => 'Connexion',
	'Login_Logout' => 'Déconnexion',
	'Login_LostYourPassword' => 'Mot de passe perdu ?',
	'Login_RemindPassword' => 'Rappeler le mot de passe',
	'Login_PasswordResetToken' => 'Clef de remise à zéro du mot de passe',
	'Login_PasswordReminder' => 'Entrez un nom d\'utilisateur ou un courriel valide, vous recevrez votre nouveau mot de passe par courriel.',
	'Login_PasswordsDoNotMatch' => 'Les mots de passe ne correspondent pas.',
	'Login_PasswordSuccessfullyChanged' => 'Mot de passe modifié avec succès!',
	'Login_InvalidUsernameEmail' => 'Nom d\'utilisateur et/ou courriel invalide.',
	'Login_InvalidOrExpiredToken' => 'La Clef est invalide ou a expiré',
	'Login_MailTopicPasswordRecovery' => 'Récupération du mot de passe',
	'Login_MailPasswordRecoveryBody' => 'Hi %1s, \n\n Votre nouveau mot de passe est : %2s \n\n Vous pouvez vous connecter maintenant ici : %3s',
	'Login_PasswordSent' => 'Le mot de passe vient juste d\'être envoyé. Veuillez vérifier vos courriels.',
	'Login_ContactAdmin' => 'Raison possible : Votre hébergeur peut avoir désactivé la fonction mail(). <br /> Veuillez contacter votre administrateur Piwik.',
	'UsersManager_UsersManagement' => 'Gestion des utilisateurs',
	'UsersManager_UsersManagementMainDescription' => 'Créez de nouveaux utilisateurs ou modifiez-les. Vous pourrez ensuite changez leurs permissions ci-dessus.',
	'UsersManager_ManageAccess' => 'Gestion des accès utilisateurs',
	'UsersManager_MainDescription' => 'Décidez quels utilisateurs ont accès à quels sites. Vous pouvez aussi changer les permissions de tous les sites d\'un seul coup.',
	'UsersManager_Sites' => 'Sites',
	'UsersManager_AllWebsites' => 'Tous les sites Internet',
	'UsersManager_ApplyToAllWebsites' => 'Appliquer à tous les sites',
	'UsersManager_User' => 'Utilisateur',
	'UsersManager_PrivNone' => 'Pas d\'accès',
	'UsersManager_PrivView' => 'Consultation',
	'UsersManager_PrivAdmin' => 'Administration',
	'UsersManager_ChangeAllConfirm' => 'Êtes-vous sûr de vouloir changer les permissions de \'%s\' sur tous les sites Internet?',
	'UsersManager_Login' => 'Nom d\'utilisateur',
	'UsersManager_Password' => 'Mot de passe',
	'UsersManager_Email' => 'Courriel',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_Edit' => 'Éditer',
	'UsersManager_AddUser' => 'Ajouter un nouvel utilisateur',
	'UsersManager_MenuUsers' => 'Utilisateurs',
	'UsersManager_DeleteConfirm_js' => 'Êtes-vous sûr de vouloir supprimer l\'utilisateur %s ?',
	'UsersManager_ExceptionLoginExists' => 'Le nom d\'utilisateur \'%s\' existe déjà.',
	'UsersManager_ExceptionEmailExists' => 'Un utilisateur avec l\'adresse courriel \'%s\' existe déjà.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'Le login doit mesurer au moins 3 charactères et contenir uniquement des lettres, des chiffres ou  \'_\' ou \'-\' ou \'.\'',
	'UsersManager_ExceptionInvalidPassword' => 'Le mot de passe doit faire entre 6 et 26 caractères.',
	'UsersManager_ExceptionInvalidEmail' => 'L\'adresse courriel est invalide.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'L\'utilisateur \'%s\' est inexistant, il n\'a pu être supprimé.',
	'UsersManager_ExceptionAdminAnonymous' => 'Vous ne pouvez pas autoriser l\'accès administrateur à l\'utilisateur Anonyme.',
	'UsersManager_ExceptionEditAnonymous' => 'L\'utilisateur Anonyme ne peut être édité ou supprimé. Il est utilisé pour identifier un utilisateur qui ne s\'est pas encoré connecté. Par exemple vous pouvez rendre vos statistiques publiques en accordant l\'accès \'vue\' à l\'utilisateur \'anonyme\'.',
	'UsersManager_ExceptionSuperUser' => 'L\'utilisateur demandé est le Super Utilisateur qui ne peut être sélectionné, édité ou supprimé depuis l\'API. Vous pouvez l\'éditer manuellement depuis le fichier de configuration.',
	'UsersManager_ExceptionUserDoesNotExist' => 'L\'utilisateur \'%s\' est inexistant.',
	'UsersManager_ExceptionAccessValues' => 'Le paramètre access doit contenir une des valeurs suivantes : [ %s ]',
	'SitesManager_Sites' => 'Sites',
	'SitesManager_WebsitesManagement' => 'Gestion des sites',
	'SitesManager_MainDescription' => 'Piwik a besoin de sites pour générer des rapports ! Ajoutez, éditez et supprimez des sites, et voyez le code JavaScript à inclure dans vos pages.',
	'SitesManager_JsTrackingTag' => 'Code JavaScript de suivit',
	'SitesManager_JsTrackingTagHelp' => 'Ci-dessous le code JavaScript à inclure dans toutes vos pages ',
	'SitesManager_ShowTrackingTag' => 'Afficher le code',
	'SitesManager_NoWebsites' => 'Vous n\'avez aucun site Internet à administrer.',
	'SitesManager_AddSite' => 'Ajouter un site',
	'SitesManager_AliasUrlHelp' => 'Il est recommandé, mais pas requis, de spécifier les URL différentes que vos utilisateurs utilisent pour accéder au site web. 
Les URL d\'alias pour un site n\'apparaitront pas dans Reférents > Sites Internet. 
Il n\'est pas nécessaire d\'entrer les URL avec et sans les www, Piwik les traite automatiquement.',
	'SitesManager_Id' => 'Id',
	'SitesManager_Name' => 'Nom',
	'SitesManager_Urls' => 'URLs',
	'SitesManager_MenuSites' => 'Sites',
	'SitesManager_DeleteConfirm_js' => 'Êtes-vous sûr de vouloir supprimer le site %s?',
	'SitesManager_ExceptionDeleteSite' => 'Impossible de supprimer le site car c\'est le seul site enregistré dans Piwik. Vous pouvez d\'abord en ajouter un nouveau, puis supprimez celui-ci.',
	'SitesManager_ExceptionNoUrl' => 'Vous devez spécifier au moins une url pour le site.',
	'SitesManager_ExceptionEmptyName' => 'Le nom du site ne peut être vide.',
	'SitesManager_ExceptionInvalidUrl' => 'L\'url \'%s\' est invalide.',
	'Installation_Installation' => 'Installation',
	'Installation_InstallationStatus' => 'Statut de l\'installation',
	'Installation_PercentDone' => '%s %% Fait',
	'Installation_NoConfigFound' => 'Le fichier de configuration de Piwik ne peut être trouvé et vous essayez d\'accéder à une page de Piwik.<br> <b>&nbsp;&nbsp;&raquo; Vous pouvez <a href=\'index.php\'>installer Piwik maintenant</a></b><br><small>Si vous avez déjà installé Piwik ne vous inquiétez pas Piwik réutilisera ces tables et leurs données.</small>',
	'Installation_DatabaseSetup' => 'Installation de la base de données',
	'Installation_DatabaseSetupServer' => 'serveur de la base de données',
	'Installation_DatabaseSetupLogin' => 'compte',
	'Installation_DatabaseSetupPassword' => 'mot de passe',
	'Installation_DatabaseSetupDatabaseName' => 'nom de la base',
	'Installation_DatabaseSetupTablePrefix' => 'préfixe des tables',
	'Installation_DatabaseSetupAdapter' => 'adaptateur',
	'Installation_DatabaseErrorConnect' => 'Erreur lors de la tentative de connexion au serveur de base de données',
	'Installation_DatabaseCheck' => 'Vérification de la base de données',
	'Installation_DatabaseServerVersion' => 'Version du serveur de base de données',
	'Installation_DatabaseCreation' => 'Création de la base de données',
	'Installation_DatabaseClientCharset' => 'Jeu de caractères client de la base de données',
	'Installation_ConnectionCharacterSetNotUtf8' => 'La connexion au serveur de base de données n\'est pas en UTF8. Ceci n\'est pas une erreur critique: <b>Piwik devrait fonctionner correctement</b>. Par soucis de cohérence il est recommandé d\'effectuer les tâches suivantes: <ul style="list-style: disc;margin-left:10px"><li>dans votre config/config.ini.php de piwik, ajoutez <code>charset = utf8</code> en dessous de la section  [database] </li><li>recompilez libmysql --with-charset=utf8</li></ul>',
	'Installation_DatabaseTimezone' => 'Fuseau horaire de la base de données',
	'Installation_TimezoneMismatch' => 'PHP date.timezone n\'est pas la même que le le fuseau horaire du serveur de base de données. Ceci pourrait causer un problème de décallage des heures et jours dans les rapports. Plus d\'informations ici %s',
	'Installation_JsTag' => 'Tag JavaScript',
	'Installation_JsTagHelp' => '<p>Pour comptabiliser tous les visiteurs vous devez copier le tag sur toutes vos pages.</p><p>Vos pages n\'ont pas besoin d\'être en PHP, Piwik fonctionne avec tout type de pages (HTML, ASP, Perl ou n\'importe quel autre langage).</p><p>Ici se trouve le code à insérer : (copiez/collez dans toutes vos pages) </p>',
	'Installation_JsTagHelpTitle' => 'Comment insérer le tag dans vos sites web?',
	'Installation_LargePiwikInstances' => 'Aide pour les instances de Piwik volumineuses',
	'Installation_JsTagArchivingHelp' => 'Pour les sites à moyen et fort trafic, lisez <a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">la page d\'explication sur comment mettre en place une page d\'auto archivage</a> pour que Piwik devienne réellement rapide!',
	'Installation_Congratulations' => 'Félicitations',
	'Installation_CongratulationsHelp' => '<p>Félicictations! Votre installation de Piwik est terminée.</p><p>Assurez vous que le code JavaScript est présent sur toutes vos pages et attendez vos premiers visiteurs!</p>',
	'Installation_ContinueToPiwik' => 'Continuer vers Piwik',
	'Installation_SetupWebsite' => 'Paramètrer un site',
	'Installation_SetupWebSiteName' => 'nom du site web',
	'Installation_SetupWebSiteURL' => 'Url du site web',
	'Installation_SetupWebsiteError' => 'Une erreur a été recontrée pendant l\'ajout du site',
	'Installation_SetupWebsiteSetupSuccess' => 	'Site %s créé avec succès!',
	'Installation_GeneralSetup' => 'Paramètres généraux',
	'Installation_GeneralSetupSuccess' => 'Paramètres génraux configurés avec succès',
	'Installation_SuperUserLogin' => 'login du super user',
	'Installation_Password' => 'mot de passe',
	'Installation_PasswordRepeat' => 'mot de passe (à nouveau)',
	'Installation_Email' => 'courriel',
	'Installation_SecurityNewsletter' => 'Envoyez moi un courriel pour les mises à jour de versions majeures de piwik ou pour les alertes de sécurité',
	'Installation_CommunityNewsletter' => 'Envoyez moi un courriel pour les nouveautés de la communauté (nouveaux plugins, nouvelles fonctionnalités, etc.)',
	'Installation_PasswordDoNotMatch' => 'Le mot de passe ne concorde pas',
	'Installation_SubmitGo' => 'Go!',
	'Installation_Requirements' => 'Pré-requis Piwik',
	'Installation_Optional' => 'Optionel',
	'Installation_Legend' => 'Légendes',
	'Installation_Extension' => 'extension',
	'Installation_SystemCheck' => 'Vérification du système',
	'Installation_SystemCheckPhp' => 'Version PHP',
	'Installation_SystemCheckExtensions' => 'Extensions requises',
	'Installation_SystemCheckDatabaseHelp' => 'Piwik requiert ou l\'extension mysqli ou les extensions pdo et pdo_mysql.',
	'Installation_SystemCheckPdoAndMysqliHelp' => "Sur un serveur linux vous pouvez compiler PHP avec les options suivantes : %s\n Dans votre php.ini, ajoutez les lignes suivantes: %s",
	'Installation_SystemCheckPhpPdoAndMysqliSite' => 'Plus d\'informations sur: <a style="color:red" href="http://php.net/pdo">PHP PDO</a> et <a style="color:red" href="http://php.net/mysqli">MYSQLI</a>.',
	'Installation_SystemCheckWinPdoAndMysqliHelp' => 'Sur un serveur windows vous pouvez ajouter les lignes suivantes à votre php.ini: %s',
	'Installation_SystemCheckSplHelp' => 'Vous devez configurer et recompiler PHP avec la librairie standart (par défaut).',
	'Installation_SystemCheckZlibHelp' => 'Vous devez reconfigurer et recompiler PHP avec le support zlib, --with-zlib.',
	'Installation_SystemCheckIconvHelp' => 'Vous devez configurer PHP et le recompiler avec le support "iconv" activé, --with-iconv.',
	'Installation_SystemCheckDomHelp' => 'DOM est une partie du coeur de PHP. Vous avez probablement besoin d\'installer le module dom ex, php-5-dom.',
	'Installation_SystemCheckJson' => 'JSON',
	'Installation_SystemCheckJsonHelp' => 'Vous devez recompiler PHP avec l\'extension "json" ou "xml" activée.',
	'Installation_SystemCheckJsonSite' => 'Plus d\'informations sur : <a style="color:red" href="http://php.net/json">PHP JSON</a>.',
	'Installation_SystemCheckXml' => 'XML',
	'Installation_SystemCheckXmlHelp' => 'Des plugins et librairies tierces pourront avoir besoin de l\'extension XML.',
	'Installation_SystemCheckXmlSite' => 'Plus d\'informations sur: <a style="color:red" href="http://php.net/xml">PHP XML</a>.',
	'Installation_SystemCheckWriteDirs' => 'Répertoires avec les droits d\'accès en écriture',
	'Installation_SystemCheckWriteDirsHelp' => 'Pour corriger les erreurs sur votre système Linux essayez de taper les commandes suivantes',
	'Installation_SystemCheckMemoryLimit' => 'Limite mémoire',
	'Installation_SystemCheckMemoryLimitHelp' => 'Sur un site à trafic important le processus d\'archivage peut prendre plus de mémoire que la limite actuelle autorisée.<br />Référez vous à la configuration memory_limit de votre php.ini si nécessaire.',
	'Installation_SystemCheckOpenURL' => 'Ouvrez l\'URL',
	'Installation_SystemCheckOpenURLHelp' => 'Abonnements à la newsletter, notifications des mises à jour, et mise à jour en un click requièrent l\'extension curl, allow_url_fopen=On, ou fsockopen() activé.',
	'Installation_SystemCheckGD' => 'GD &gt; 2.x (graphiques)',
	'Installation_SystemCheckGDHelp' => 'Les sparklines (petits graphs) ne fonctionneront pas.',
	'Installation_SystemCheckFunctions' => 'Fonctions requises',
	'Installation_SystemCheckTimeLimitHelp' => 'Sur un site à trafic important le processus d\'archivage peut prendre plus de temps qu\'il n\'est déjà autorisé.<br /> Référez vous à la configuration max_execution_time de votre php.ini si nécessaire.',
	'Installation_SystemCheckMailHelp' => 'Les Feedback (commentaires) et mots de passe perdus ne pourront être envoyés sans la fonciton mail().',
	'Installation_SystemCheckError' => 'Une erreur s\'est produite — elle doit être corrigée avant de pouvoir continuer',
	'Installation_SystemCheckWarning' => 'Piwik fonctionnera normalement mais certaines fonctionnalités seront manquantes',
	'Installation_Tables' => 'Création des tables',
	'Installation_TablesWithSameNamesFound' => 'Environ %s tables dans votre base de données %s ont le même nom que celles que Piwik essaie de créer.',
	'Installation_TablesFound' => 'Les tables suivantes ont été trouvées dans la base de données',
	'Installation_TablesWarningHelp' => 'Vous pouvez choisir de réutiliser les tables de la base de données existante ou sélectionner une nouvelle installation pour effacer toutes les données existantes dans la base de données.',
	'Installation_TablesReuse' => 'Réutiliser les tables existantes',
	'Installation_TablesDelete' => 'Supprimer les tables détectées',
	'Installation_TablesDeletedSuccess' => 'Tables Piwik existantes supprimées avec succès',
	'Installation_TablesCreatedSuccess' => 'Tables crées avec succès!',
	'Installation_DatabaseCreatedSuccess' => 'Base de données %s crée avec succès !',
	'Installation_GoBackAndDefinePrefix' => 'Retournez à la page précédente et définissez le préfixe pour les tables Piwik',
	'Installation_ConfirmDeleteExistingTables' => 'Etes vous sûr de vouloir supprimer les tables : %s de votre base de données? ATTENTION: LES DONNEES SERONT DEFINITIVEMENT PERDUES!',
	'Installation_Welcome' => 'Bienvenue!',
	'Installation_WelcomeHelp' => '<p>Piwik est une application d\'analyse du web Open Source qui vous permet d\'obtenir facilement les informations que vous désirez sur vos visiteurs.</p>	<p>Ce procédé est divisé en %s étapes faciles et vous prendra 5 minutes environ.</p>',
	'Installation_ErrorInvalidState' => 'Erreur: il semble que vous essayez de sauter une étape du processus d\'installation, ou vous avez désactivé les coookies, ou le fichier de configuration de Piwik est déjà créé. %sAssurez vous que les cookies sont bien activés%s et retournez %s à la première page d\'installation %s.',
	'Provider_WidgetProviders' => 'Fournisseurs d\'accès à Internet',
	'Provider_ColumnProvider' => 'FAI',
	'Provider_SubmenuLocationsProvider' => 'Situation géographique et FAI',
	'Goals_ColumnConversions' => 'Conversions',
	'Goals_ColumnConversionRate' => 'Taux de Conversion',
	'Goals_ColumnRevenue' => 'Revenu',
	'DBStats_DatabaseUsage' => 'Utilisation de la base de données',
	'DBStats_MainDescription' => 'Piwil conserve toutes vos analyses web dans la base de données MySQL. Présentement, les tables utilisent %s.',
	'DBStats_LearnMore' => 'Pour en apprendre plus sur la manière de Piwik de traiter les données et sur comment faire fonctionner Piwik correctement pour les sites à trafic moyen et fort, veuillez consulter cette documentation %s.',
	'DBStats_Table' => 'Table',
	'DBStats_RowNumber' => 'Numéro de rangée',
	'DBStats_DataSize' => 'Taille des données',
	'DBStats_IndexSize' => 'Taille de l\'index',
	'DBStats_TotalSize' => 'Taille totale',
	'TranslationsAdmin_MenuTranslations' => 'Traductions',
	'TranslationsAdmin_MenuLanguages' => 'Langues',
	'TranslationsAdmin_Plugin' => 'Plugin',
	'TranslationsAdmin_Definition' => 'Définition',
	'TranslationsAdmin_DefaultString' => 'Chaine par défaut (English)',
	'TranslationsAdmin_TranslationString' => 'Traduction (Langue actuelle : %s)',
	'TranslationsAdmin_Translations' => 'Traductions',
	'TranslationsAdmin_FixPermissions' => 'Veuillez définir les propriétés des fichiers systèmes',
	'TranslationsAdmin_AvailableLanguages' => 'Langues disponibles',
	'TranslationsAdmin_AddLanguage' => 'Ajouter langue',
	'TranslationsAdmin_LanguageCode' => 'Code langue',
	'TranslationsAdmin_Export' => 'Exporter langue',
	'TranslationsAdmin_Import' => 'Importer langue',
);
